searchData={"content_type":"text/markdown","items":[{"doc":"A durable event-driven workflow engine SDK for Elixir. \n    Read the  documentation  and get started in minutes.\n   \n   \n       \n       \n       \n       \n     \n       \n       \n   \n \n\n# [Inngest](https://www.inngest.com) Elixir SDK\n\nInngest's Elixir SDK allows you to create event-driven, durable workflows in your\nexisting API — without new infrastructure.\n\nIt's useful if you want to build reliable software without worrying about queues,\nevents, subscribers, workers, or other complex primitives such as concurrency,\nparallelism, event batching, or distributed debounce. These are all built in.","ref":"Inngest.html","title":"Inngest","type":"module"},{"doc":"The Elixir SDK can be downloaded from [Hex](https://hex.pm/packages/inngest). Add it\nto your list of dependencies in `mix.exs`\n\n``` elixir\n# mix.exs\ndef deps do\n  [\n    {:inngest, \"~> 0.2\"}\n  ]\nend\n```\n\n#","ref":"Inngest.html#module-installation","title":"Installation - Inngest","type":"module"},{"doc":"This is a basic example of what an Inngest function will look like.\n\nA Module can be turned into an Inngest function easily by using the `Inngest.Function`\nmacro.\n\n``` elixir\ndefmodule MyApp.AwesomeFunction do\n  use Inngest.Function\n\n  @func %FnOpts{id: \"awesome-fn\", name: \"Awesome Function\"} # The id and name of the function\n  @trigger %Trigger{event: \"func/awesome\"} # The event this function will react to\n\n  @impl true\n  def exec(_ctx, _input) do\n    IO.inspect(\"Do something\")\n\n    {:ok, \"hello world\"}\n  end\nend\n```\n\nAnd just like that, you have an Inngest function that will react to an event called `func/awesome`.\n`Inngest.Function.exec/2` will then be called by the SDK to run and execute the logic.\n\n##","ref":"Inngest.html#module-example","title":"Example - Inngest","type":"module"},{"doc":"The above example will be no different from other background processing libraries, so let's take a\nlook at a more complicated version. Which should provide you an idea what is capable with Inngest.\n\n``` elixir\ndefmodule MyApp.AwesomeFunction do\n  use Inngest.Function\n\n  @func %FnOpts{id: \"awesome-fn\", name: \"Awesome Function\"} # The id and name of the function\n  @trigger %Trigger{event: \"func/awesome\"} # The event this function will react to\n\n  @impl true\n  def exec(ctx, %{step: step} = input) do\n    IO.inspect(\"Starting function...\")\n\n    %{greet: greet} =\n      # A return value wrapped in a `step` are memorized, meaning\n      # it's guaranteed to be idempotent.\n      # if it fails, it'll be retried.\n      step.run(ctx, \"step1\", fn ->\n        %{greet: \"hello\"}\n      end)\n\n    # Sleeping will pause the execution from running, and function\n    # will be reinvoked when time is up.\n    step.sleep(ctx, \"wait-a-little\", \"10s\")\n\n    %{name: name} =\n      step.run(ctx, \"retrieve-user\", fn ->\n        # retrieve user from here\n        %{name: user_name}\n      end)\n\n    # There are times you want to wait for something to happen before\n    # continue on the workflow. `wait_for_event` allows exactly that.\n    evt = step.wait_for_event(\"wait-for-registration-complete\", %{\n      event: \"user/register.completed\",\n      timeout: \"1h\"\n    })\n\n    # You might want to trigger some other workflow, sending an event\n    # will trigger the functions that are registered against the `event`.\n    step.send_event(\"completed-work\", %{\n      name: \"func/awesome.completed\",\n      data: %{name: name}\n    })\n\n    {:ok, %{greetings: \"#{greet} #{name}\", registered: is_nil(evt)}}\n  end\nend\n```\n\nSee the **[guides](https://hexdocs.pm/inngest)** for more details regarding use cases and how each macros can be used.","ref":"Inngest.html#module-advanced","title":"Advanced - Inngest","type":"module"},{"doc":"","ref":"Inngest.html#send/1","title":"Inngest.send/1","type":"function"},{"doc":"Module representing an Inngest client (subject to change).","ref":"Inngest.Client.html","title":"Inngest.Client","type":"module"},{"doc":"Send one or a batch of events to Inngest","ref":"Inngest.Client.html#send/2","title":"Inngest.Client.send/2","type":"function"},{"doc":"Module representing an Inngest event.\n\nAs you might guess, `Events` are the fundamentals of an event driven system. Inngest starts and ends with events. An event is the trigger for functions to start, resume and can also hold the data for functions to operate on.\n\nAn `Inngest.Event` looks like this:\n\n    %{\n      id: \"\",\n      name: \"event/awesome\",\n      data: { \"hello\": \"world\" },\n      ts: 1690156151,\n      v: \"2023.04.14.1\"\n    }\n\n##","ref":"Inngest.Event.html","title":"Inngest.Event","type":"module"},{"doc":"The `id` field in an event payload is used for deduplication. Setting this field will make sure that only one of the events (the first one) with a similar `id` is processed.\n\n##","ref":"Inngest.Event.html#module-id-string-optional","title":"id - `string` optional - Inngest.Event","type":"module"},{"doc":"The name of the event. We recommend using lowercase dot notation for names, prepending ` /` with a slash for organization.\n\n##","ref":"Inngest.Event.html#module-name-string-required","title":"name - `string` required - Inngest.Event","type":"module"},{"doc":"Any data to associate with the event. Will be serialized as JSON.\n\n##","ref":"Inngest.Event.html#module-data-map-required","title":"data - `map` required - Inngest.Event","type":"module"},{"doc":"A timestamp integer representing the unix time (in milliseconds) at which the event occurred. Defaults to the time the Inngest receives the event if not provided.\n\n##","ref":"Inngest.Event.html#module-ts-integer-optional","title":"ts - `integer` optional - Inngest.Event","type":"module"},{"doc":"A version identifier for a particular event payload. e.g. `2023-04-14.1`","ref":"Inngest.Event.html#module-v-string-optional","title":"v - `string` optional - Inngest.Event","type":"module"},{"doc":"Construct an Event struct from a map.","ref":"Inngest.Event.html#from/1","title":"Inngest.Event.from/1","type":"function"},{"doc":"","ref":"Inngest.Event.html#t:t/0","title":"Inngest.Event.t/0","type":"type"},{"doc":"Function configuration options.\n\nSee the typespec for all available options.","ref":"Inngest.FnOpts.html","title":"Inngest.FnOpts","type":"module"},{"doc":"Configure how the function should consume batches of events ([reference](https://www.inngest.com/docs/guides/batching))\n\n**max_size** - `number` required\n\nThe maximum number of events a batch can have. Current limit is `100`.\n\n**timeout** - `string` required\n\nHow long to wait before invoking the function with the batch even if it's not full.\nCurrent permitted values are from `1s` to `60s`.","ref":"Inngest.FnOpts.html#t:batch_events/0","title":"Inngest.FnOpts.batch_events/0","type":"type"},{"doc":"Define an event that can be used to cancel a running or sleeping function ([reference](https://www.inngest.com/docs/functions/cancellation))\n\n**event** - `string` required\n\nThe event name which will be used to cancel\n\n**match** - `string` optional\n\nThe property to match the event trigger and the cancelling event, using dot-notation\ne.g. `data.userId`\n\n**if** - `string` optional\n\nTODO\n\n**timeout** - `string` optional\n\nThe amount of time to wait to receive the cancelling event.\ne.g. `30m`, `3h`, or `2d`","ref":"Inngest.FnOpts.html#t:cancel_on/0","title":"Inngest.FnOpts.cancel_on/0","type":"type"},{"doc":"","ref":"Inngest.FnOpts.html#t:cancel_option/0","title":"Inngest.FnOpts.cancel_option/0","type":"type"},{"doc":"Limit the number of concurrently running functions ([reference](https://www.inngest.com/docs/functions/concurrency))\n\n**limit** - `string` required\n\nThe maximum number of concurrently running steps.\n\n**key** - `string` optional\n\nA unique key expression for which to restrict concurrently running steps to. The expression is evaluated for each triggering event and a unique key is generate.","ref":"Inngest.FnOpts.html#t:concurrency/0","title":"Inngest.FnOpts.concurrency/0","type":"type"},{"doc":"","ref":"Inngest.FnOpts.html#t:concurrency_option/0","title":"Inngest.FnOpts.concurrency_option/0","type":"type"},{"doc":"Options to configure function debounce ([reference](https://www.inngest.com/docs/reference/functions/debounce)).\n\n**period** - `string` required\n\nThe time period of which to set the limit. The period begins when the first matching event is received. How long to wait before invoking the function with the batch even if it's not full. Current permitted values are from `1s` to `7d (168h)`.\n\n**key** - `string` optional\n\nA unique key expression to apply the debounce to. The expression is evaluated for each triggering event.\n\nExpressions are defined using the [Common Expression Language (CEL)](https://github.com/google/cel-go) with the original event accessible using dot-notation. Examples:\n\n* Debounce per customer id: `event.data.customer_id`\n* Debounce per account and email address: `event.data.account_id + \"-\" + event.user.email`","ref":"Inngest.FnOpts.html#t:debounce/0","title":"Inngest.FnOpts.debounce/0","type":"type"},{"doc":"A unique identifier for your function. This should not change between deploys.","ref":"Inngest.FnOpts.html#t:id/0","title":"Inngest.FnOpts.id/0","type":"type"},{"doc":"A key expression which is used to prevent duplicate events from triggering a function more than once in 24 hours.\n\nThis is equivalent to setting `rate_limit` with a `key`, a limit of `1` and period of `24hr`.\n\nExpressions are defined using the [Common Expression Language (CEL)](https://github.com/google/cel-go) with the original event accessible using dot-notation. Examples:\n\n* Only run once for each customer id: `event.data.customer_id`\n* Only run once for each account and email address: `event.data.account_id + \"-\" + event.user.email`","ref":"Inngest.FnOpts.html#t:idempotency/0","title":"Inngest.FnOpts.idempotency/0","type":"type"},{"doc":"A name for your function. If defined, this will be shown in the UI as a friendly display name instead of the ID.","ref":"Inngest.FnOpts.html#t:name/0","title":"Inngest.FnOpts.name/0","type":"type"},{"doc":"Prioritize specific function runs ahead of others ([reference](https://www.inngest.com/docs/reference/functions/run-priority))\n\n**run** - `string` optional\n\nAn expression which must return an integer between -600 and 600 (by default), with higher return values resulting in a higher priority.\nSee [reference](https://www.inngest.com/docs/reference/functions/run-priority) for more information.","ref":"Inngest.FnOpts.html#t:priority/0","title":"Inngest.FnOpts.priority/0","type":"type"},{"doc":"Options to configure how to rate limit function execution ([reference](https://www.inngest.com/docs/reference/functions/rate-limit))\n\n**limit** - `number` required\n\nThe maximum number of functions to run in the given time period.\n\n**period** - `number` required\n\nThe time period of which to set the limit. The period begins when the first matching event is received.\nHow long to wait before invoking the function with the batch even if it's not full.\nCurrent permitted values are from `1s` to `60s`.\n\n**key** - `string` optional\n\nA unique key expression to apply the limit to. The expression is evaluated for each triggering event.\n\nExpressions are defined using the [Common Expression Language (CEL)](https://github.com/google/cel-go) with the original event accessible using dot-notation. Examples:\n\n* Rate limit per customer id: `event.data.customer_id`\n* Rate limit per account and email address: `event.data.account_id + \"-\" + event.user.email`\n\n#","ref":"Inngest.FnOpts.html#t:rate_limit/0","title":"Inngest.FnOpts.rate_limit/0","type":"type"},{"doc":"This option cannot be used with `cancel_on` and `rate_limit`.","ref":"Inngest.FnOpts.html#t:rate_limit/0-note","title":"Note - Inngest.FnOpts.rate_limit/0","type":"type"},{"doc":"Configure the number of times the function will be retried from `0` to `20`. Default: `3`","ref":"Inngest.FnOpts.html#t:retries/0","title":"Inngest.FnOpts.retries/0","type":"type"},{"doc":"","ref":"Inngest.FnOpts.html#t:t/0","title":"Inngest.FnOpts.t/0","type":"type"},{"doc":"Module to be used within user code to setup an Inngest function.\nMaking it servable and invokable.\n\nCreating an Inngest function is as easy as using `Inngest.Function`. It creates\nthe necessary attributes and handlers it needs to work with Inngest.\n\n    defmodule MyApp.Inngest.SomeJob do\n      use Inngest.Function\n      alias Inngest.{FnOpts, Trigger}\n\n      @func %FnOpts{id: \"my-func\", name: \"some job\"}\n      @trigger %Trigger{event: \"job/foobar\"}\n\n      @impl true\n      def exec(ctx, input) do\n        {:ok, \"hello world\"}\n      end\n\n      # Optional handler to handle failures when the function fails\n      # after all retries are exhausted.\n      def handle_failure(ctx, %{step: step} = _args) do\n        _ = step.run(ctx, \"handle-failure\", fn ->\n          \"Do something here\"\n        end)\n\n        {:ok, \"error handled\"}\n      end\n    end","ref":"Inngest.Function.html","title":"Inngest.Function","type":"behaviour"},{"doc":"Assign `Inngest.FnOpts` to `@func` to configure the function. See `Inngest.FnOpts`\nto see what options are available.","ref":"Inngest.Function.html#module-function-options","title":"Function Options - Inngest.Function","type":"behaviour"},{"doc":"A trigger is causes a function to run. One of the following is required, and\nthey're mutually exclusive.\n\n#### `event` - `string` and/or `expression` - `string`\n\nThe name of the event that will trigger this event to run.\nWe recommend it to name it with a prefix so it's a easier pattern to identify\nwhat it's for.\n\ne.g. `auth/signup.email.send`\n\n#### `cron` - `string`\n\nA [unix-cron](https://crontab.guru/) compatible schedule string.\n\nOptional timezone prefix, e.g. `TZ=Europe/Paris 0 12 * * 5`.","ref":"Inngest.Function.html#module-trigger","title":"Trigger - Inngest.Function","type":"behaviour"},{"doc":"The method to be called when the Inngest function starts execution.\n\nOnly this method needs to be provided.","ref":"Inngest.Function.html#c:exec/2","title":"Inngest.Function.exec/2","type":"callback"},{"doc":"Returns the function name","ref":"Inngest.Function.html#c:name/0","title":"Inngest.Function.name/0","type":"callback"},{"doc":"Returns the function's human-readable ID, such as \"sign-up-flow\"","ref":"Inngest.Function.html#c:slug/0","title":"Inngest.Function.slug/0","type":"callback"},{"doc":"Returns the event name or schedule that triggers the function","ref":"Inngest.Function.html#c:trigger/0","title":"Inngest.Function.trigger/0","type":"callback"},{"doc":"Context to be passed to steps in functions.","ref":"Inngest.Function.Context.html","title":"Inngest.Function.Context","type":"module"},{"doc":"","ref":"Inngest.Function.Context.html#t:t/0","title":"Inngest.Function.Context.t/0","type":"type"},{"doc":"Input provides the events, and step tools for an Inngest function","ref":"Inngest.Function.Input.html","title":"Inngest.Function.Input","type":"module"},{"doc":"","ref":"Inngest.Function.Input.html#t:t/0","title":"Inngest.Function.Input.t/0","type":"type"},{"doc":"Struct representing a function trigger.\n\nCan either be an `event` or a `cron`, and they're mutually exclusive.","ref":"Inngest.Trigger.html","title":"Inngest.Trigger","type":"module"},{"doc":"# defining an event trigger\n    %Inngest.Trigger{event: \"auth/signup.email\"}\n\n    # defining a cron trigger, and can accept a timezone\n    %Inngest.Trigger{cron: \"TZ=America/Los_Angeles * * * * *\"}","ref":"Inngest.Trigger.html#module-examples","title":"Examples - Inngest.Trigger","type":"module"},{"doc":"","ref":"Inngest.Trigger.html#t:t/0","title":"Inngest.Trigger.t/0","type":"type"},{"doc":"Router module for Inngest to be integrated with apps that\nhave a router.\n\nCurrently available options are\n- `Phoenix`\n- `Plug.Router`","ref":"Inngest.Router.html","title":"Inngest.Router","type":"module"},{"doc":"use Inngest.Router, :phoenix\n    use Inngest.Router, :plug","ref":"Inngest.Router.html#module-examples","title":"Examples - Inngest.Router","type":"module"},{"doc":"","ref":"Inngest.Router.html#phoenix/0","title":"Inngest.Router.phoenix/0","type":"function"},{"doc":"","ref":"Inngest.Router.html#plug/0","title":"Inngest.Router.plug/0","type":"function"},{"doc":"Router module expected to be used with a `Phoenix` router.","ref":"Inngest.Router.Phoenix.html","title":"Inngest.Router.Phoenix","type":"module"},{"doc":"use Inngest.Router, :phoenix","ref":"Inngest.Router.Phoenix.html#module-examples","title":"Examples - Inngest.Router.Phoenix","type":"module"},{"doc":"","ref":"Inngest.Router.Phoenix.html#inngest/2","title":"Inngest.Router.Phoenix.inngest/2","type":"macro"},{"doc":"Router module expected to be used with a `Plug.Router`.","ref":"Inngest.Router.Plug.html","title":"Inngest.Router.Plug","type":"module"},{"doc":"use Inngest.Router, :plug","ref":"Inngest.Router.Plug.html#module-examples","title":"Examples - Inngest.Router.Plug","type":"module"},{"doc":"","ref":"Inngest.Router.Plug.html#inngest/2","title":"Inngest.Router.Plug.inngest/2","type":"macro"},{"doc":"Handles signature related operations","ref":"Inngest.Signature.html","title":"Inngest.Signature","type":"module"},{"doc":"","ref":"Inngest.Signature.html#hashed_signing_key/1","title":"Inngest.Signature.hashed_signing_key/1","type":"function"},{"doc":"","ref":"Inngest.Signature.html#normalize_key/1","title":"Inngest.Signature.normalize_key/1","type":"function"},{"doc":"","ref":"Inngest.Signature.html#sign/3","title":"Inngest.Signature.sign/3","type":"function"},{"doc":"","ref":"Inngest.Signature.html#signing_key_valid?/4","title":"Inngest.Signature.signing_key_valid?/4","type":"function"},{"doc":"A custom Plug parser for caching raw request body","ref":"Inngest.CacheBodyReader.html","title":"Inngest.CacheBodyReader","type":"module"},{"doc":"","ref":"Inngest.CacheBodyReader.html#read_body/2","title":"Inngest.CacheBodyReader.read_body/2","type":"function"},{"doc":"","ref":"Inngest.CacheBodyReader.html#read_cached_body/1","title":"Inngest.CacheBodyReader.read_cached_body/1","type":"function"},{"doc":"Error indicating there's a misconfiguration when attempting to use `batch_events`.","ref":"Inngest.BatchEventConfigError.html","title":"Inngest.BatchEventConfigError","type":"exception"},{"doc":"Error indicating there's a misconfiguration when attempting to use `cancel_on`.","ref":"Inngest.CancelConfigError.html","title":"Inngest.CancelConfigError","type":"exception"},{"doc":"Error indicating there's a misconfiguration when attempting to use `concurrency`.","ref":"Inngest.ConcurrencyConfigError.html","title":"Inngest.ConcurrencyConfigError","type":"exception"},{"doc":"Error indicating there's a misconfiguration when attempting to use `debounce`.","ref":"Inngest.DebounceConfigError.html","title":"Inngest.DebounceConfigError","type":"exception"},{"doc":"Error indicating there's a misconfiguration when attempting to use `idempotency`.","ref":"Inngest.IdempotencyConfigError.html","title":"Inngest.IdempotencyConfigError","type":"exception"},{"doc":"Error signaling to not retry","ref":"Inngest.NonRetriableError.html","title":"Inngest.NonRetriableError","type":"exception"},{"doc":"Error indicating there's a misconfiguration when attempting to use `priority`.","ref":"Inngest.PriorityConfigError.html","title":"Inngest.PriorityConfigError","type":"exception"},{"doc":"Error indicating there's a misconfiguration when attempting to use `rate_limit`.","ref":"Inngest.RateLimitConfigError.html","title":"Inngest.RateLimitConfigError","type":"exception"},{"doc":"Error to control how long to wait before attempting a retry\n\n#","ref":"Inngest.RetryAfterError.html","title":"Inngest.RetryAfterError","type":"exception"},{"doc":"This works with retry `attempts` and will not exceed the set `attempts`.","ref":"Inngest.RetryAfterError.html#module-note","title":"NOTE - Inngest.RetryAfterError","type":"exception"},{"doc":"","ref":"Inngest.Test.Case.RetriableError.YoloError.html","title":"Inngest.Test.Case.RetriableError.YoloError","type":"exception"},{"doc":"# How does it work?\n\nCheck **[here][inngest]** to see how Inngest works.\n\n[inngest]: https://www.inngest.com/product/how-inngest-works?ref=elixir-sdk","ref":"how-it-works.html","title":"How does it work?","type":"extras"},{"doc":"# Installation\n\nThe Elixir SDK can be downloaded from [Hex][hex]. Add it to your list of dependencies\nin `mix.exs`:\n\n``` elixir\n# mix.exs\ndef deps do\n  [\n    {:inngest, \"~> 0.2\"}\n  ]\nend\n```\n\nThen run `mix deps.get` to download the package.","ref":"installation.html","title":"Installation","type":"extras"},{"doc":"#","ref":"installation.html#note","title":"Note - Installation","type":"extras"},{"doc":"The Elixir SDK currently uses `Tesla` for handling HTTP requests. While this might\nnot be ideal for some folks, it's the only option that can swap out the underlying HTTP\nlibraries while still providing a similar interface.\nAnd it was the easiest to get something out quickly while still providing that portability.\n\nWe will be looking into removing this dependency completely in the future with\n[`Mint`](https://hexdocs.pm/mint/api-reference.html) or just pure\n[`:httpc`](https://www.erlang.org/doc/man/httpc.html).\n\n#","ref":"installation.html#http-client","title":"HTTP client - Installation","type":"extras"},{"doc":"If you currently have a preferred adapter you want to use, please take a look at their\n[Adapters][tesla-adapters] page.\n\nOtherwise, it will utilize the default `Hackney` adapter.\n\n[hex]: https://hex.pm/packages/inngest\n[tesla-adapters]: https://hexdocs.pm/tesla/1.7.0/readme.html#adapters","ref":"installation.html#tesla-adapters","title":"Tesla adapters - Installation","type":"extras"},{"doc":"# Configuration\n\nThere are a couple of configurations you should be aware of before deploying.\n\n- [App Name](#app-name)\n- [App Host](#app-host)\n- [Env](#env)\n- [Event Key](#event-key)\n- [Signing Key](#signing-key)\n- [Inngest Env](#inngest-env)\n\n#","ref":"config.html","title":"Configuration","type":"extras"},{"doc":"Default value: `InngestApp`.\n\nThe app name to be registered with Inngest.\n\n##","ref":"config.html#app-name","title":"App Name - Configuration","type":"extras"},{"doc":"`INNGEST_APP_NAME`\n\n##","ref":"config.html#environment-variable","title":"Environment variable - Configuration","type":"extras"},{"doc":"``` elixir\nconfig :inngest, app_name: \"MyApp\"\n```\n\n#","ref":"config.html#config","title":"Config - Configuration","type":"extras"},{"doc":"Default value: `\"http://127.0.0.1:4000\"`\n\nThe app host to be used when deployed.\n\n##","ref":"config.html#app-host","title":"App Host - Configuration","type":"extras"},{"doc":"`INNGEST_APP_HOST`\n\n##","ref":"config.html#environment-variable","title":"Environment variable - Configuration","type":"extras"},{"doc":"``` elixir\nconfig :inngest, app_host: \"https://myapp.com\"\n```\n\n#","ref":"config.html#config","title":"Config - Configuration","type":"extras"},{"doc":"Default value: `nil`\n\nThis value determines the environment the app is on, and decides if your app\nshould connect to the Dev server or Inngest Cloud.\n\n##","ref":"config.html#env","title":"Env - Configuration","type":"extras"},{"doc":"`INNGEST_ENV`\n\n##","ref":"config.html#environment-variable","title":"Environment variable - Configuration","type":"extras"},{"doc":"``` elixir\nconfig :inngest, env: :dev\n```\n\n##","ref":"config.html#config","title":"Config - Configuration","type":"extras"},{"doc":"Make sure to set the value to `:dev` when you're developing locally.\nOtherwise it won't connect to the Dev Server and try to connect to Inngest Cloud\ninstead.\n\n#","ref":"config.html#note","title":"NOTE - Configuration","type":"extras"},{"doc":"Default value: `nil`\n\nThe key used for sending events. It's not required for the Dev Server but required\nfor Inngest Cloud.\n\n##","ref":"config.html#event-key","title":"Event Key - Configuration","type":"extras"},{"doc":"`INNGEST_EVENT_KEY`\n\n##","ref":"config.html#environment-variable","title":"Environment variable - Configuration","type":"extras"},{"doc":"``` elixir\nconfig :inngest, event_key: \"key\"\n```\n\n#","ref":"config.html#config","title":"Config - Configuration","type":"extras"},{"doc":"Default value: `nil`\n\nThe key used for verifying request signatures from the executor to your app, when\ntriggering function runs.\n\nIt's not required for the Dev Server but required for Inngest Cloud.\n\n##","ref":"config.html#signing-key","title":"Signing Key - Configuration","type":"extras"},{"doc":"`INNGEST_SIGNING_KEY`\n\n##","ref":"config.html#environment-variable","title":"Environment variable - Configuration","type":"extras"},{"doc":"``` elixir\nconfig :inngest, signing_key: \"key\"\n```\n\n#","ref":"config.html#config","title":"Config - Configuration","type":"extras"},{"doc":"Default value: `false`\n\nWhen [passing a `path` to `inngest`](serve-api.html) macro in your router, this enables the functions\nto be evaluated during runtime instead of compile time, which is the default.\n\nThis exists for the sore purpose of easing development feedback, and should not be\nused for non development workloads.\n\n``` elixir\nconfig :inngest, path_runtime_eval: true\n```","ref":"config.html#path-runtime-evaluation","title":"Path runtime evaluation - Configuration","type":"extras"},{"doc":"# Events\n\nSee `Inngest.Event` for reference.","ref":"events.html","title":"Events","type":"extras"},{"doc":"Use `Inngest.Client.send/1` or you can send it to Dev server via `curl`:\n\n```bash\ncurl -X POST 'http://127.0.0.1:8288/e/test' \\\n  -d '{ \"name\": \"test/event\", \"data\": { \"hello\": \"world\" } }'\n```\n\nTo events to the [Inngest Cloud](https://app.inngest.com):\n\n```bash\ncurl -X POST 'https://inn.gs/e/:event_key' \\\n  -d '{ \"name\": \"event-name\", \"data\": {} }'\n```","ref":"events.html#sending-events","title":"Sending events - Events","type":"extras"},{"doc":"# Handling failures\n\n#","ref":"failure_handler.html","title":"Handling failures","type":"extras"},{"doc":"When a function fails, either after exhausting all the retries, or simply\nutilizing `Inngest.NonRetriableError`, it will emit an event called\n`inngest/function.failed`.\n\nThe structure of the event will look something like the following.\n\n```json\n{\n  \"name\": \"inngest/function.failed\",\n  \"data\": {\n    \"error\": {\n      \"error\": \"invalid status code: 500\",\n      \"message\": \"** (ErlangError) Erlang error: \\\"YOLO!!!\\\"\\n    (inngest 0.1.9) test/support/cases/retriable_error.ex:20: anonymous fn/0 in Inngest.Test.Case.RetriableError.exec/2\\n    (inngest 0.1.9) lib/inngest/step_tool.ex:19: Inngest.StepTool.run/3\\n    (inngest 0.1.9) test/support/cases/retriable_error.ex:19: Inngest.Test.Case.RetriableError.exec/2\\n    (inngest 0.1.9) lib/inngest/router/invoke.ex:90: Inngest.Router.Invoke.invoke/3\\n    (inngest 0.1.9) lib/inngest/router/invoke.ex:65: Inngest.Router.Invoke.exec/2\\n    (inngest 0.1.9) deps/plug/lib/plug/router.ex:246: anonymous fn/4 in Inngest.Test.PlugRouter.dispatch/2\\n    (telemetry 1.2.1) /home/darwin/workspace/ex_inngest/deps/telemetry/src/telemetry.erl:321: :telemetry.span/3\\n    (inngest 0.1.9) deps/plug/lib/plug/router.ex:242: Inngest.Test.PlugRouter.dispatch/2\\n\",\n      \"name\": \"Error\"\n    },\n    \"event\": {\n      \"data\": {},\n      \"id\": \"01HGF86PM2CGFPZWF22HSCQFNE\",\n      \"name\": \"test/plug.retriable\",\n      \"ts\": 1701318974082,\n      \"user\": {}\n    },\n    \"function_id\": \"retriable-fn\",\n    \"run_id\": \"01HGF86PM90KRQQP27VJZK4BXP\"\n  },\n  \"id\": \"01HGF86VDYZWVBK9K5FT27W6T7\",\n  \"ts\": 1701318979006\n}\n```\n\nSee our [documentation](https://www.inngest.com/docs/reference/functions/handling-failures#the-inngest-function-failed-event)\nfor more details about the `inngest/function.failed` event.\n\n#","ref":"failure_handler.html#failure-event","title":"Failure event - Handling failures","type":"extras"},{"doc":"To handle the error event, you can add a method in your `Inngest.Function` module to handle the failure event.\n\n```\ndefmodule MyApp.Inngest.SomeJob do\n  use Inngest.Function\n\n  @func %FnOpts{id: \"my-func\", name: \"some job\"}\n  @trigger %Trigger{event: \"job/foobar\"}\n\n  @impl true\n  def exec(ctx, input) do\n    {:ok, \"hello world\"}\n  end\n\n  # Optional handler to handle failures when the function fails\n  # after all retries are exhausted.\n  def handler_failure(ctx, %{step: step} = input) do\n    # this is just like `exec`, except the event will always be\n    # `inngest/function.failed` with the error body\n    _ = step.run(ctx, \"handle-failure\", fn ->\n      \"handle\"\n    end)\n\n    {:ok, \"error handled\"}\n  end\nend\n```","ref":"failure_handler.html#handling-the-failure-event","title":"Handling the failure event - Handling failures","type":"extras"},{"doc":"# Dev server\n\n![Dev server screenshot](https://github.com/darwin67/ex_inngest/assets/5746693/d8b80b54-5238-4c4b-bf76-6e15bee590a7)\n\nInngest provides a dev server you can run locally to aid with local development. You\ncan start the Dev server with:\n\n```sh\nnpx inngest-cli@latest dev\n```\n\nThis will download the latest version available and you should be able to access it\nvia http://localhost:8288.\n\nIf you prefer to download the CLI locally:\n\n```sh\nnpm i -g inngest-cli\n# or\nnpm i -g inngest-cli@ \n```\n\nthen:\n\n``` sh\ninngest-cli dev\n```","ref":"dev-server.html","title":"Dev server","type":"extras"},{"doc":"The Dev server will try to auto discover apps and functions via `http://localhost:3000/api/inngest`\nby default. However, apps like Phoenix typically runs on port `4000`. You can provide the auto\ndiscovery URL when starting the Dev server:\n\n``` sh\nnpx inngest-cli@latest dev -u http://127.0.0.1:4000/api/inngest\n```\n\nThis will tell the Dev server to look at `http://127.0.0.1:4000/api/inngest` to discover and\nregister apps/functions.","ref":"dev-server.html#auto-discovery","title":"Auto discovery - Dev server","type":"extras"},{"doc":"For more options with the `Dev server`, use the `--help` option:\n\n```bash\ninngest-cli dev --help\n```\n\n#","ref":"dev-server.html#other-options","title":"Other options - Dev server","type":"extras"},{"doc":"The `inngest-cli` is a single executable binary. It's packaged and distributed with NPM for\nthe time being, but could change in the future.","ref":"dev-server.html#note","title":"Note - Dev server","type":"extras"},{"doc":"# Serving the API\n\nInngest works by serving an HTTP API endpoint which exposes your functions for us to\ncall on-demand. The first thing you'll need to do is to add and serve the Inngest API\nin your project.","ref":"serve-api.html","title":"Serving the API","type":"extras"},{"doc":"The Elixir SDK provides an `inngest` macro, that will setup the required API endpints\nto your router. The recommended path is `/api/inngest` since it makes it obvious where\nthe endpoints are, but you can change it to whatever you see fit.\n\n``` elixir\ndefmodule MyApp.Router do\n  use Inngest.Router, :plug\n\n  inngest(\"/api/inngest\", path: \"inngest/**/*.ex\")\nend\n```\n\nAccepted arguments for the `inngest` macros are\n\n- `path`\n- `opts`\n\n##","ref":"serve-api.html#setting-up","title":"Setting up - Serving the API","type":"extras"},{"doc":"- `func` - the list of modules. e.g. `[MyApp.EventFn, MyApp.CronFn]`\n- `path` - the path or paths to the inngest function modules. e.g. `path: \"inngest/**/*.ex\"`\n\nAmong the options, `path` takes precedence.\n\nThere are 2 routers available based on what you're using for exposing HTTP endpoints for\nyour apps:\n\n- `Inngest.Router.Plug`\n- `Inngest.Router.Phoenix`","ref":"serve-api.html#opts","title":"opts - Serving the API","type":"extras"},{"doc":"# How to deploy\n\nSince there are no serverless runtime for Elixir, deployment to the Cloud will either\ninvolve the Cloud UI or via `curl`.\n\nCheck **[here][inngest]** to see how to deploy.\n\n[inngest]: https://www.inngest.com/docs/deploy?ref=elixir-sdk#deploying-manually-via-the-inngest-dashboard","ref":"deploy.html","title":"How to deploy","type":"extras"},{"doc":"# Working with environments\n\nCheck **[here][inngest]** to see how to work with different environments.\n\n[inngest]: https://www.inngest.com/docs/platform/environments?ref=elixir-sdk","ref":"environments.html","title":"Working with environments","type":"extras"},{"doc":"# Creating an Event key\n\nTo send events to Inngest for non local workloads, you will need an `event key` to do so.\n\nCheck **[here][inngest]** to see how to create an event key.\n\nAlso check the [`configuration`][config] page to see how to set the event key for your app.\n\n[inngest]: https://www.inngest.com/docs/events/creating-an-event-key?ref=elixir-sdk\n[config]: config.html","ref":"event-key.html","title":"Creating an Event key","type":"extras"},{"doc":"# Usage Limits\n\nWe have some usage limits on the Cloud to provide a stable system.\n\nCheck **[here][inngest]** for more details.\n\n[inngest]: https://www.inngest.com/docs/usage-limits/inngest?elixir-sdk","ref":"limits.html","title":"Usage Limits","type":"extras"},{"doc":"# CHANGELOG\n\nAll notable changes to this project will be documented in this file.\n\n## [0.2.1] - 2024-05-15\n\n#","ref":"changelog.html","title":"CHANGELOG","type":"extras"},{"doc":"- Fix: Remove test app from `mod` (#78)\n\n#","ref":"changelog.html#bug-fixes","title":"Bug Fixes - CHANGELOG","type":"extras"},{"doc":"- Chore: update license to Apache2 (#76)\n\n## [0.2.0] - 2023-12-04\n\n#","ref":"changelog.html#miscellaneous-tasks","title":"Miscellaneous Tasks - CHANGELOG","type":"extras"},{"doc":"- Fix: add additional restrictions when using batching (#72)\n\n#","ref":"changelog.html#bug-fixes","title":"Bug Fixes - CHANGELOG","type":"extras"},{"doc":"- Docs: Update docs to prepare for 0.2 release (#62)\n\n#","ref":"changelog.html#documentation","title":"Documentation - CHANGELOG","type":"extras"},{"doc":"- Feat: add event batching to function configuration\n- Feat: Change approach for SDK (#59)\n- Feat: Add general retry handling and non retriable error (#63)\n- Feat: Add failure handler (#64)\n- Feat: debounce support (#65)\n- Feat: support batching (#66)\n- Feat: rate limit support (#67)\n- Feat: concurrency support (#68)\n- Feat: idempotency support (#69)\n- Feat: cancel on support (#70)\n- Feat: priority support (#71)\n\n#","ref":"changelog.html#features","title":"Features - CHANGELOG","type":"extras"},{"doc":"- Chore: update ci.yml\n- Chore: Clean up (#60)\n- Chore: Integration tests (#61)\n- Chore: update hashing method for steps (#75)\n\n## [0.1.9] - 2023-08-01\n\n#","ref":"changelog.html#miscellaneous-tasks","title":"Miscellaneous Tasks - CHANGELOG","type":"extras"},{"doc":"- Fix: make sure to read existing queries (#55)\n\n## [0.1.8] - 2023-07-31\n\n#","ref":"changelog.html#bug-fixes","title":"Bug Fixes - CHANGELOG","type":"extras"},{"doc":"- Fix: make certain fields in Event as optional types\n\n## [0.1.7] - 2023-07-31\n\n#","ref":"changelog.html#bug-fixes","title":"Bug Fixes - CHANGELOG","type":"extras"},{"doc":"- Feat: Allow non map return values\n- Feat: Allow no return value with just :ok for step runs\n\n#","ref":"changelog.html#features","title":"Features - CHANGELOG","type":"extras"},{"doc":"- Chore: Change type to list of Events\n\n## [0.1.6] - 2023-07-28\n\n#","ref":"changelog.html#miscellaneous-tasks","title":"Miscellaneous Tasks - CHANGELOG","type":"extras"},{"doc":"- Fix: path takes precedence when passed to `inngest` macro\n\n#","ref":"changelog.html#bug-fixes","title":"Bug Fixes - CHANGELOG","type":"extras"},{"doc":"- Docs: update `inngest` macro docs\n\n## [0.1.5] - 2023-07-28\n\n## [0.1.4] - 2023-07-28\n\n#","ref":"changelog.html#documentation","title":"Documentation - CHANGELOG","type":"extras"},{"doc":"- Chore: Fix release workflow with proper escapes (#49)\n\n## [0.1.3] - 2023-07-27\n\n#","ref":"changelog.html#miscellaneous-tasks","title":"Miscellaneous Tasks - CHANGELOG","type":"extras"},{"doc":"- Fix compile errors due to parallel compilation conflicts (#45)\n\n## [0.1.2] - 2023-07-27\n\n## [0.1.1] - 2023-07-27\n\n## [0.1.0] - 2023-07-27","ref":"changelog.html#bug-fixes","title":"Bug Fixes - CHANGELOG","type":"extras"}]}